==> jc-1.4.0.tar.gz: java/lang/VMString.c <==
// final class java.lang.VMString

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 4bf65894ae9af31d java_lang_VMString
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 14fe490ec89fb98 java_lang_ref_WeakReference
// @dep_class e23d3f140ad06459 java_util_WeakHashMap

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_Throwable
// @dep_header java_lang_VMString
// @dep_header java_lang_ref_WeakReference
// @dep_header java_util_WeakHashMap

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/Throwable.h"
#include "java/lang/VMString.h"
#include "java/lang/ref/WeakReference.h"
#include "java/util/WeakHashMap.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final java.util.WeakHashMap internTable
static _jc_field _jc_java_lang_VMString$field_info$internTable = {
	.name=		"internTable",
	.signature=	"Ljava/util/WeakHashMap;",
	.class=		&_jc_java_lang_VMString$type,
	.type=		&_jc_java_util_WeakHashMap$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_lang_VMString$fields_struct, internTable),
};

// Fields
static _jc_field *const _jc_java_lang_VMString$fields[] = {
	&_jc_java_lang_VMString$field_info$internTable
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// private static final void <clinit>()
//

static _jc_linenum _jc_java_lang_VMString$linenum_table$_clinit$a816641e0ba8bfef[];

static const unsigned char _jc_java_lang_VMString$param_ptypes$_clinit$a816641e0ba8bfef[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMString$method_info$_clinit$a816641e0ba8bfef = {
	.name=			"<clinit>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMString$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMString$param_ptypes$_clinit$a816641e0ba8bfef,
	.signature_hash=	_JC_JLONG(0xa816641e0ba8bfef),
	.access_flags=		_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_VMString$method$_clinit$a816641e0ba8bfef,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMString$linenum_table$_clinit$a816641e0ba8bfef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMString, _clinit$a816641e0ba8bfef);

void
_jc_java_lang_VMString$method$_clinit$a816641e0ba8bfef(_jc_env *const env)
{
	struct _jc_java_util_WeakHashMap$object *r0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	_JC_LINE_NUMBER(61);				// 0
	r0 = _JC_NEW(env, java_util_WeakHashMap);
	_JC_INVOKE_NONVIRTUAL(env, java_util_WeakHashMap, _init$7cb044ce4fb0ada8, 0, r0, 11, _JC_FCONST(0x3f, 0x40, 0x0, 0x0));
	_JC_STATIC_FIELD(env, java_lang_VMString, internTable, 1) = r0;
	return;
}

//
// static final java.lang.String intern(java.lang.String)
//

static _jc_linenum _jc_java_lang_VMString$linenum_table$intern$d704e0dabc0fade6[];

static _jc_trap_info _jc_java_lang_VMString$trap_table$intern$d704e0dabc0fade6[] = {
	_JC_TRAP(_JC_NULL, 1, 2),
	_JC_TRAP(_JC_NULL, 5, 6),
	_JC_TRAP(_JC_NULL, 3, 4),
};

static const unsigned char _jc_java_lang_VMString$param_ptypes$intern$d704e0dabc0fade6[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMString$param_types$intern$d704e0dabc0fade6[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_java_lang_VMString$method_info$intern$d704e0dabc0fade6 = {
	.name=			"intern",
	.signature=		"(Ljava/lang/String;)Ljava/lang/String;",
	.class=			&_jc_java_lang_VMString$type,
	.param_types=		&_jc_java_lang_VMString$param_types$intern$d704e0dabc0fade6,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_lang_VMString$param_ptypes$intern$d704e0dabc0fade6,
	.signature_hash=	_JC_JLONG(0xd704e0dabc0fade6),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_VMString$method$intern$d704e0dabc0fade6,
	.num_parameters=	1,
	.u= { .exec= {
	  .trap_table_len=	3,
	  .trap_table=		_jc_java_lang_VMString$trap_table$intern$d704e0dabc0fade6,
	  .u= {
	    .linenum= {
	      .len=	8,
	      .table=	_jc_java_lang_VMString$linenum_table$intern$d704e0dabc0fade6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMString, intern$d704e0dabc0fade6);

_jc_java_lang_String$object *
_jc_java_lang_VMString$method$intern$d704e0dabc0fade6(_jc_env *const env, _jc_java_lang_String$object *param0)
{
	struct _jc_java_lang_String$object *r0;
	struct _jc_java_util_WeakHashMap$object *volatile r1;
	struct _jc_java_lang_Throwable$object *volatile r2;
	struct _jc_java_lang_ref_WeakReference$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_util_WeakHashMap$object *r5;
	struct _jc_java_lang_Object$object *r6;
	_jc_catch_frame	catch;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	// Define exception targets
	_JC_DEFINE_TRAPS(env, catch, &_jc_java_lang_VMString$method_info$intern$d704e0dabc0fade6, &&label0, &&label0, &&label0);

	r0 = param0;
	_JC_LINE_NUMBER(75);				// 0
	goto label1;

label0:
	_JC_TRAP_REGION(catch, 0);
	_JC_PERIODIC_CHECK(env);
	r2 = _JC_CAUGHT_EXCEPTION(env);
	_JC_TRAP_REGION(catch, 1);
	_JC_MONITOR_EXIT(env, r1);
	_JC_TRAP_REGION(catch, 2);
	_JC_THROW(env, r2);

label1:
	_JC_TRAP_REGION(catch, 2);
	r5 = _JC_STATIC_FIELD(env, java_lang_VMString, internTable, 1);
	r1 = r5;
	_JC_MONITOR_ENTER(env, r5);
	_JC_TRAP_REGION(catch, 3);
	_JC_LINE_NUMBER(77);				// 1
	r5 = _JC_STATIC_FIELD(env, java_lang_VMString, internTable, 1);
	r6 = _JC_INVOKE_VIRTUAL(env, java_util_WeakHashMap, get$b30461fc5ea13399, r5, r0);
	r3 = _JC_CAST(env, &_jc_java_lang_ref_WeakReference$type, r6);
	_JC_LINE_NUMBER(78);				// 2
	if (r3 == _JC_NULL)
		goto label2;
	_JC_LINE_NUMBER(80);				// 3
	r6 = _JC_INVOKE_VIRTUAL(env, java_lang_ref_Reference, get$a27f05608bfbd09b, r3);
	r4 = _JC_CAST_FINAL(env, &_jc_java_lang_String$type, r6);
	_JC_LINE_NUMBER(83);				// 4
	if (r4 == _JC_NULL)
		goto label2;
	_JC_LINE_NUMBER(84);				// 5
	_JC_MONITOR_EXIT(env, r1);
	_JC_TRAP_REGION(catch, 4);
	_JC_CANCEL_TRAPS(env, catch);
	return r4;

label2:
	_JC_TRAP_REGION(catch, 5);
	_JC_LINE_NUMBER(86);				// 6
	r5 = _JC_STATIC_FIELD(env, java_lang_VMString, internTable, 1);
	r3 = _JC_NEW(env, java_lang_ref_WeakReference);
	_JC_REF_FIELD(env, r3, java_lang_ref_Reference, referent) = r0;
	_JC_INVOKE_VIRTUAL(env, java_util_WeakHashMap, put$3bd1c078a0faa8da, r5, r0, r3);
	_JC_MONITOR_EXIT(env, r1);
	_JC_TRAP_REGION(catch, 6);
	_JC_LINE_NUMBER(88);				// 7
	_JC_CANCEL_TRAPS(env, catch);
	return r0;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_lang_VMString$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_lang_VMString$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMString$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMString$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMString$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_lang_VMString$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMString$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMString, _init$52f4ad9f2989aeee);

void
_jc_java_lang_VMString$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_lang_VMString$object *this)
{
	struct _jc_java_lang_VMString$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(53);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_VMString$methods[] = {
	&_jc_java_lang_VMString$method_info$_clinit$a816641e0ba8bfef,
	&_jc_java_lang_VMString$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_lang_VMString$method_info$intern$d704e0dabc0fade6
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_java_lang_VMString$fields_struct _jc_java_lang_VMString$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_VMString$instanceof_hash_bucket_29[] = {
	&_jc_java_lang_VMString$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_VMString$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_VMString$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[29]=	_jc_java_lang_VMString$instanceof_hash_bucket_29,
	[113]=	_jc_java_lang_VMString$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_VMString$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/ref/Reference",	_JC_JLONG(0x77273604094666c7) },
	{ "java/lang/ref/WeakReference",	_JC_JLONG(0x14fe490ec89fb98) },
	{ "java/util/WeakHashMap",	_JC_JLONG(0xe23d3f140ad06459) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_VMString$vtype _jc_java_lang_VMString$type = {
    .type= {
	.name=			"java/lang/VMString",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x4bf65894ae9af31d),
		.source_file=		"VMString.java",
		.instance_size=		sizeof(_jc_java_lang_VMString$refs) + sizeof(_jc_java_lang_VMString$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_java_lang_VMString$fields) / sizeof(*_jc_java_lang_VMString$fields),
		.fields=		_jc_java_lang_VMString$fields,
		.num_methods=		sizeof(_jc_java_lang_VMString$methods) / sizeof(*_jc_java_lang_VMString$methods),
		.methods=		_jc_java_lang_VMString$methods,
		.instanceof_hash_table=	_jc_java_lang_VMString$instanceof_hash_table,
		.class_fields=		&_jc_java_lang_VMString$class_fields,
		.num_class_depends=		sizeof(_jc_java_lang_VMString$class_depends) / sizeof(*_jc_java_lang_VMString$class_depends),
		.class_depends=		_jc_java_lang_VMString$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_VMString= {
	},
    }
};

==> jc-1.4.5.tar.gz: java/lang/VMString.c <==
// final class java.lang.VMString

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 4bf65894ae9af31d java_lang_VMString
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 14fe490ec89fb98 java_lang_ref_WeakReference
// @dep_class e23d3f140ad06459 java_util_WeakHashMap

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_Throwable
// @dep_header java_lang_VMString
// @dep_header java_lang_ref_WeakReference
// @dep_header java_util_WeakHashMap

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/Throwable.h"
#include "java/lang/VMString.h"
#include "java/lang/ref/WeakReference.h"
#include "java/util/WeakHashMap.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private static final java.util.WeakHashMap internTable
static _jc_field _jc_java_lang_VMString$field_info$internTable = {
	.name=		"internTable",
	.signature=	"Ljava/util/WeakHashMap;",
	.class=		&_jc_java_lang_VMString$type,
	.type=		&_jc_java_util_WeakHashMap$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_lang_VMString$fields_struct, internTable),
};

// Fields
static _jc_field *const _jc_java_lang_VMString$fields[] = {
	&_jc_java_lang_VMString$field_info$internTable
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// private static final void <clinit>()
//

static _jc_linenum _jc_java_lang_VMString$linenum_table$_clinit$a816641e0ba8bfef[];

static const unsigned char _jc_java_lang_VMString$param_ptypes$_clinit$a816641e0ba8bfef[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMString$method_info$_clinit$a816641e0ba8bfef = {
	.name=			"<clinit>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMString$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMString$param_ptypes$_clinit$a816641e0ba8bfef,
	.signature_hash=	_JC_JLONG(0xa816641e0ba8bfef),
	.access_flags=		_JC_ACC_PRIVATE|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_VMString$method$_clinit$a816641e0ba8bfef,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMString$linenum_table$_clinit$a816641e0ba8bfef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMString, _clinit$a816641e0ba8bfef);

void _JC_JCNI_ATTR
_jc_java_lang_VMString$method$_clinit$a816641e0ba8bfef(_jc_env *const env)
{
	struct _jc_java_util_WeakHashMap$object *r0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	_JC_LINE_NUMBER(61);				// 0
	r0 = _JC_NEW(env, java_util_WeakHashMap);
	_JC_INVOKE_NONVIRTUAL(env, java_util_WeakHashMap, _init$7cb044ce4fb0ada8, 0, r0, 11, _JC_FCONST(0x3f, 0x40, 0x0, 0x0));
	_JC_STATIC_FIELD(env, java_lang_VMString, internTable, 1) = r0;
	return;
}

//
// static final java.lang.String intern(java.lang.String)
//

static _jc_linenum _jc_java_lang_VMString$linenum_table$intern$d704e0dabc0fade6[];

static _jc_trap_info _jc_java_lang_VMString$trap_table$intern$d704e0dabc0fade6[] = {
	_JC_TRAP(_JC_NULL, 1, 2),
	_JC_TRAP(_JC_NULL, 5, 6),
	_JC_TRAP(_JC_NULL, 3, 4),
};

static const unsigned char _jc_java_lang_VMString$param_ptypes$intern$d704e0dabc0fade6[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMString$param_types$intern$d704e0dabc0fade6[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_java_lang_VMString$method_info$intern$d704e0dabc0fade6 = {
	.name=			"intern",
	.signature=		"(Ljava/lang/String;)Ljava/lang/String;",
	.class=			&_jc_java_lang_VMString$type,
	.param_types=		&_jc_java_lang_VMString$param_types$intern$d704e0dabc0fade6,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_lang_VMString$param_ptypes$intern$d704e0dabc0fade6,
	.signature_hash=	_JC_JLONG(0xd704e0dabc0fade6),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_VMString$method$intern$d704e0dabc0fade6,
	.num_parameters=	1,
	.u= { .exec= {
	  .trap_table_len=	3,
	  .trap_table=		_jc_java_lang_VMString$trap_table$intern$d704e0dabc0fade6,
	  .u= {
	    .linenum= {
	      .len=	8,
	      .table=	_jc_java_lang_VMString$linenum_table$intern$d704e0dabc0fade6
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMString, intern$d704e0dabc0fade6);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_java_lang_VMString$method$intern$d704e0dabc0fade6(_jc_env *const env, _jc_java_lang_String$object *param0)
{
	struct _jc_java_lang_String$object *r0;
	struct _jc_java_util_WeakHashMap$object *volatile r1;
	struct _jc_java_lang_Throwable$object *volatile r2;
	struct _jc_java_lang_ref_WeakReference$object *r3;
	struct _jc_java_lang_String$object *r4;
	struct _jc_java_util_WeakHashMap$object *r5;
	struct _jc_java_lang_Object$object *r6;
	_jc_catch_frame	catch;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	// Define exception targets
	_JC_DEFINE_TRAPS(env, catch, &_jc_java_lang_VMString$method_info$intern$d704e0dabc0fade6, &&label0, &&label0, &&label0);

	r0 = param0;
	_JC_LINE_NUMBER(75);				// 0
	goto label1;

label0:
	_JC_TRAP_REGION(catch, 0);
	_JC_PERIODIC_CHECK(env);
	r2 = _JC_CAUGHT_EXCEPTION(env);
	_JC_TRAP_REGION(catch, 1);
	_JC_MONITOR_EXIT(env, r1);
	_JC_TRAP_REGION(catch, 2);
	_JC_THROW(env, r2);

label1:
	_JC_TRAP_REGION(catch, 2);
	r5 = _JC_STATIC_FIELD(env, java_lang_VMString, internTable, 1);
	r1 = r5;
	_JC_MONITOR_ENTER(env, r5);
	_JC_TRAP_REGION(catch, 3);
	_JC_LINE_NUMBER(77);				// 1
	r5 = _JC_STATIC_FIELD(env, java_lang_VMString, internTable, 1);
	r6 = _JC_INVOKE_VIRTUAL(env, java_util_WeakHashMap, get$b30461fc5ea13399, r5, r0);
	r3 = _JC_CAST(env, &_jc_java_lang_ref_WeakReference$type, r6);
	_JC_LINE_NUMBER(78);				// 2
	if (r3 == _JC_NULL)
		goto label2;
	_JC_LINE_NUMBER(80);				// 3
	r6 = _JC_INVOKE_VIRTUAL(env, java_lang_ref_Reference, get$a27f05608bfbd09b, r3);
	r4 = _JC_CAST_FINAL(env, &_jc_java_lang_String$type, r6);
	_JC_LINE_NUMBER(83);				// 4
	if (r4 == _JC_NULL)
		goto label2;
	_JC_LINE_NUMBER(84);				// 5
	_JC_MONITOR_EXIT(env, r1);
	_JC_TRAP_REGION(catch, 4);
	_JC_CANCEL_TRAPS(env, catch);
	return r4;

label2:
	_JC_TRAP_REGION(catch, 5);
	_JC_LINE_NUMBER(86);				// 6
	r5 = _JC_STATIC_FIELD(env, java_lang_VMString, internTable, 1);
	r3 = _JC_NEW(env, java_lang_ref_WeakReference);
	_JC_REF_FIELD(env, r3, java_lang_ref_Reference, referent) = r0;
	_JC_INVOKE_VIRTUAL(env, java_util_WeakHashMap, put$3bd1c078a0faa8da, r5, r0, r3);
	_JC_MONITOR_EXIT(env, r1);
	_JC_TRAP_REGION(catch, 6);
	_JC_LINE_NUMBER(88);				// 7
	_JC_CANCEL_TRAPS(env, catch);
	return r0;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_lang_VMString$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_lang_VMString$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMString$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMString$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMString$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_lang_VMString$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMString$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMString, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_lang_VMString$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_lang_VMString$object *this)
{
	struct _jc_java_lang_VMString$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(53);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_VMString$methods[] = {
	&_jc_java_lang_VMString$method_info$_clinit$a816641e0ba8bfef,
	&_jc_java_lang_VMString$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_lang_VMString$method_info$intern$d704e0dabc0fade6
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_java_lang_VMString$fields_struct _jc_java_lang_VMString$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_VMString$instanceof_hash_bucket_29[] = {
	&_jc_java_lang_VMString$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_VMString$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_VMString$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[29]=	_jc_java_lang_VMString$instanceof_hash_bucket_29,
	[101]=	_jc_java_lang_VMString$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_VMString$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/Throwable",	_JC_JLONG(0x3be5c3c4fdd59a1e) },
	{ "java/lang/ref/Reference",	_JC_JLONG(0x77273604094666c7) },
	{ "java/lang/ref/WeakReference",	_JC_JLONG(0x14fe490ec89fb98) },
	{ "java/util/WeakHashMap",	_JC_JLONG(0xe23d3f140ad06459) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_VMString$vtype _jc_java_lang_VMString$type = {
    .type= {
	.name=			"java/lang/VMString",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x4bf65894ae9af31d),
		.source_file=		"VMString.java",
		.instance_size=		sizeof(_jc_java_lang_VMString$refs) + sizeof(_jc_java_lang_VMString$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_java_lang_VMString$fields) / sizeof(*_jc_java_lang_VMString$fields),
		.fields=		_jc_java_lang_VMString$fields,
		.num_methods=		sizeof(_jc_java_lang_VMString$methods) / sizeof(*_jc_java_lang_VMString$methods),
		.methods=		_jc_java_lang_VMString$methods,
		.instanceof_hash_table=	_jc_java_lang_VMString$instanceof_hash_table,
		.class_fields=		&_jc_java_lang_VMString$class_fields,
		.num_class_depends=		sizeof(_jc_java_lang_VMString$class_depends) / sizeof(*_jc_java_lang_VMString$class_depends),
		.class_depends=		_jc_java_lang_VMString$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_VMString= {
	},
    }
};
